[aXSL-commit] SF.net SVN: axsl:[2985] trunk/axsl/axsl-font/src/main /java/org/axsl/font/FontConsume
An API for XSL-FO.
Status: Alpha
Brought to you by:
victormote
|
From: <vic...@us...> - 2026-03-08 15:02:27
|
Revision: 2985
http://sourceforge.net/p/axsl/code/2985
Author: victormote
Date: 2026-03-08 15:02:24 +0000 (Sun, 08 Mar 2026)
Log Message:
-----------
Change return type from List to Collection, for greater implementation flexibility.
Modified Paths:
--------------
trunk/axsl/axsl-font/src/main/java/org/axsl/font/FontConsumer.java
Modified: trunk/axsl/axsl-font/src/main/java/org/axsl/font/FontConsumer.java
===================================================================
--- trunk/axsl/axsl-font/src/main/java/org/axsl/font/FontConsumer.java 2026-03-08 14:35:09 UTC (rev 2984)
+++ trunk/axsl/axsl-font/src/main/java/org/axsl/font/FontConsumer.java 2026-03-08 15:02:24 UTC (rev 2985)
@@ -32,6 +32,7 @@
import org.axsl.value.FontVariant;
import org.axsl.value.FontWeight;
+import java.util.Collection;
import java.util.List;
/**
@@ -145,10 +146,10 @@
FontUse getFontUse(Font font, Encoding encoding);
/**
* Returns a list of the {@link ConsumerFont} instances that have been used by this FontConsumer.
* @return The list of {@link ConsumerFont} instances used by this FontConsumer.
*/
- List<? extends ConsumerFont> getUsedFonts();
+ Collection<ConsumerFont> getUsedFonts();
/**
* <p>Optimizes the fonts used by this FontConsumer.
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -145,10 +146,10 @@
FontUse getFontUse(Font font, Encoding encoding);
/**
- * Returns a list of the {@link ConsumerFont} instances that have been used by this FontConsumer.
- * @return The list of {@link ConsumerFont} instances used by this FontConsumer.
+ * Returns the collection of {@link ConsumerFont} instances that have been used by this FontConsumer.
+ * @return The collection of {@link ConsumerFont} instances used by this FontConsumer.
*/
|